#' May All Data be Reproducible And Transparent (madrat) *
#' 
#' Package provides a basic framework which should improve reproducibility and transparency in data processing. 
#' It provides functionality such as automatic meta data creation and management, rudimentary quality management, 
#' data caching, work-flow management an data aggregation.
#' 
#' * The title is a wish not a promise. By no means we expect this package to deliver everything what is needed to
#' achieve full reproducibility and transparency, but we believe that it supports efforts in this direction. 
#' 
#' @name madrat-package
#' @aliases madrat-package madrat
"_PACKAGE"
